use gtk::gio::ListStore;
use xmpp::BareJid;

use std::collections::HashMap;
use std::sync::{Arc, RwLock};

use crate::poezio_logs::load_logs;
use crate::Message;

pub type InnerMessageStore = HashMap<BareJid, ListStore>;

#[derive(Clone, Debug, Default)]
pub struct MessageStore {
    /// complete message history
    store: Arc<RwLock<InnerMessageStore>>,
}

impl<'a> MessageStore {
    pub fn new() -> Self {
        Self::default()
    }

    pub fn with_jid(&self, jid: &BareJid) -> ListStore {
        self.store
            .write()
            .unwrap()
            .entry(jid.clone())
            .or_insert(load_logs(jid.as_str()))
            .clone()
    }

    pub fn insert_message(&self, jid: &BareJid, message: &Message) {
        self.with_jid(jid).append(message);
    }
}
